@@ -7,7 +7,6 @@ to authorize request which is being made to Firebase.
 import logging
 import typing as t
 import uuid
-from copy import deepcopy
 from datetime import datetime, timedelta
 from pathlib import PurePath
 from urllib.parse import urljoin
@@ -16,6 +15,7 @@ import httpx
 from google.auth.transport.requests import Request as GoogleRequest  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from .encoders import aps_encoder
 from .messages import (
     AndroidConfig,
     AndroidNotification,
@@ -194,7 +194,7 @@ class AsyncFirebaseClient:
         alert: str = None,
         badge: int = None,
         sound: str = None,
-        content_available: bool = True,
+        content_available: bool = False,
         category: str = None,
         thread_id: str = None,
         mutable_content: bool = True,
@@ -266,14 +266,15 @@ class AsyncFirebaseClient:
                     ),
                     badge=badge,
                     sound="default" if alert and sound is None else sound,
-                    content_available=content_available,
                     category=category,
                     thread_id=thread_id,
                     mutable_content=mutable_content,
                     custom_data=custom_data or {},
+                    content_available=True if content_available else None,
                 ),
             ),
         )
+
         return apns_config
 
     async def _prepare_headers(self):
@@ -362,17 +363,13 @@ class AsyncFirebaseClient:
         )
 
         # Assemble APNS custom data properly
-        apns_custom_data: t.Dict[str, t.Any] = {}
         has_apns_config = True if apns and apns.payload else False
         if has_apns_config:
-            apns_custom_data = deepcopy(apns.payload.aps.custom_data)  # type: ignore
-            apns.payload.aps.custom_data.clear()  # type: ignore
+            message.apns.payload = aps_encoder(apns.payload.aps)  # type: ignore
 
         push_notification: t.Dict[str, t.Any] = cleanup_firebase_message(
             PushNotification(message=message, validate_only=dry_run)
         )
-        if has_apns_config:
-            push_notification["message"]["apns"]["payload"].update(apns_custom_data)
 
         if len(push_notification["message"]) == 1:
             logging.warning("No data has been provided to construct push notification payload")
